#
# spec file for package autofs
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           autofs
Url:            http://www.kernel.org/pub/linux/daemons/autofs/v5/
BuildRequires:  autoconf
BuildRequires:  bison
BuildRequires:  e2fsprogs
BuildRequires:  flex
BuildRequires:  krb5-devel
BuildRequires:  libtirpc-devel
BuildRequires:  libxml2-devel
BuildRequires:  module-init-tools
BuildRequires:  nfs-client
BuildRequires:  openldap2-devel
Version:        5.0.5
Release:        14.21.1
Summary:        A Kernel-Based Automounter
License:        GPL-2.0+
Group:          System/Daemons
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source:         ftp://ftp.kernel.org/pub/linux/daemons/autofs/v5/%{name}-%{version}.tar.bz2
Source1:        sysconfig.autofs
Source3:        autofs.schema
Source4:        README.SuSE.ldap
Source5:        README.SuSE
Source7:        NetworkManager-autofs
Source8:        get-upstream-patches
%define patchdate 20110613
Patch0:         autofs-%{version}-upstream-patches-%{patchdate}.bz2
Patch1:         autofs-5.0.5-invalid-ghost-dirs.patch
Patch2:         autofs-5.0.5-fix-null-cache-deadlock.patch
Patch3:         autofs-5.0.5-fix-ipv6-name-for-lookup.patch
Patch4:         autofs-5.0.5-fix-libtirpc-ipv6-check.patch
Patch5:         autofs-5.0.6-fix-ipv6-name-for-lookup-fix.patch
Patch6:         autofs-5.0.6-fix-paged-query-more-results-check.patch
Patch7:         autofs-5.0.6-fix-dumpmaps-not-reading-maps.patch
Patch8:         autofs-5.0.6-fix-result-null-check-in-read_one_map.patch
Patch9:         autofs-5.0.6-fix-ldap-result-leaks-on-error-paths.patch
Patch10:        autofs-5.0.6-fix-fix-ldap-result-leaks-on-error-paths.patch
Patch11:        autofs-5.0.6-code-analysis-fixes-1.patch
Patch12:        autofs-5.0.6-fix-wait-for-master-source-mutex.patch
Patch13:        autofs-5.0.6-fix-submount-shutdown-race.patch
Patch14:        autofs-5.0.6-fix-fix-map-source-check-in-file-lookup.patch
Patch15:        autofs-5.0.6-fix-ipv6-name-lookup-check.patch
Patch16:        autofs-5.0.6-fix-ipv6-rpc-calls.patch
Patch17:        autofs-5.0.6-fix-ipv6-configure-check.patch
Patch18:        autofs-5.0.6-fix-rpc-build-error.patch
Patch19:        autofs-5.0.6-fix-libtirpc-name-typo.patch
Patch20:        autofs-5.0.6-task-use-after-free.patch
Patch100:       autofs-suse-auto_master_default.patch
Patch101:       autofs-suse-autofs_init.patch
Patch102:       autofs-suse-build.patch
PreReq:         %fillup_prereq %insserv_prereq aaa_base
Recommends:     nfs-client

%description
AutoFS is a kernel-based automounter for Linux.  It automatically
mounts filesystems when you use them, and unmounts them later when
you are not using them.  This can include network filesystems, CD-ROMs,
floppies, and so forth.



Authors:
--------
    H. Peter Anvin <hpa@transmeta.com>
    Ian Kent <raven@themaw.net>

%prep
%setup
cp %{SOURCE3} .
cp %{SOURCE4} .
cp %{SOURCE5} .
#
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch100 -p1
%patch101 -p1
%patch102 -p1

%build
SUSE_ASNEEDED=0
rm -f configure
autoconf -f
./configure %{_target_cpu}-suse-linux \
            --libdir=%{_libdir} --mandir=%{_mandir} \
            --with-confdir=/etc/sysconfig \
            --disable-mount-locking \
            --enable-forced-shutdown \
            --enable-ignore-busy \
            --with-libtirpc \
            --with-hesiod=no \
            --with-sasl
make all DONTSTRIP=1 LOCAL_CFLAGS="$RPM_OPT_FLAGS %(getconf LFS_CFLAGS)"

%install
make install INSTALLROOT=$RPM_BUILD_ROOT
ln -s ../../etc/init.d/autofs $RPM_BUILD_ROOT/usr/sbin/rcautofs
ln -s %{_mandir}/man8/autofs.8.gz $RPM_BUILD_ROOT/%{_mandir}/man8/rcautofs.8.gz
mkdir -p $RPM_BUILD_ROOT/var/adm/fillup-templates
install -m 644 %{S:1} $RPM_BUILD_ROOT/var/adm/fillup-templates/sysconfig.autofs
mkdir -p $RPM_BUILD_ROOT/etc/NetworkManager/dispatcher.d
install -m 755 %{S:7} $RPM_BUILD_ROOT/etc/NetworkManager/dispatcher.d/autofs
# will be installed by fillup scripts 
rm -f $RPM_BUILD_ROOT/etc/sysconfig/autofs

%clean
rm -rf %{buildroot}

%post
if /sbin/chkconfig -c autofs 3; then
	%{insserv_force_if_yast autofs}
fi
%{fillup_only -n autofs}

%preun
%{stop_on_removal autofs}

%postun
%{restart_on_update autofs}
%{insserv_cleanup}

%files
%defattr (-, root, root)
/var/adm/fillup-templates/sysconfig.autofs
%config(noreplace) /etc/auto.master
%config(noreplace) /etc/auto.misc
%config(noreplace) /etc/auto.net
%config(noreplace) /etc/auto.smb
%config(noreplace) /etc/autofs_ldap_auth.conf
%config /etc/init.d/autofs
%dir /etc/NetworkManager
%dir /etc/NetworkManager/dispatcher.d
/etc/NetworkManager/dispatcher.d/autofs
%doc COPYRIGHT README README.changer README.ncpfs README.replicated-server
%doc README.smbfs README.v5.release autofs.schema README.active-restart
%doc README.SuSE README.SuSE.ldap 
%dir %{_libdir}/autofs/
%{_libdir}/autofs/
%{_mandir}/man5/*
%{_mandir}/man8/*
%{_sbindir}/rcautofs
%{_sbindir}/automount

%changelog
* Thu Feb  2 2012 lchiquitto@suse.com
- second AutoFS maintenance update for openSUSE 11.4 (bnc#744873)
* Thu Feb  2 2012 lchiquitto@suse.com
- fix segfault caused by an use after free in st_queue_handler()
  (bnc#727392)
* Thu Feb  2 2012 lchiquitto@suse.com
- disable "--as-needed" to make sure automount will be linked
  against libtirpc (bnc#742846)
- fix typo in libtirpc file name
* Thu Feb  2 2012 lchiquitto@suse.com
- import bug fixes from the upstream repository:
  * fix ipv6 name for lookup
  * fix libtirpc ipv6 check
  * fix ipv6 name for lookup fix
  * fix paged query more results check
  * fix dumpmaps not reading maps
  * fix result null check in read_one_map() (bnc#707715)
  * fix LDAP result leaks on error paths
  * fix fix LDAP result leaks on error paths (bnc#730245)
  * code analysis fixes part 1
  * fix wait for master source mutex
  * fix submount shutdown race
  * fix fix map source check in file lookup
  * fix ipv6 name lookup check
  * fix ipv6 rpc calls
  * fix ipv6 configure check
  * fix rpc build error
* Thu Feb  2 2012 lchiquitto@suse.com
- add autoconf as buildrequire to avoid implicit dependency
- build against libtirpc since glibc's rpc code is deprecated
* Fri Aug 26 2011 lchiquitto@suse.com
- first AutoFS maintenance update for openSUSE 11.4 (bnc#700085)
* Tue Jun 14 2011 lchiquitto@novell.com
- rpm spec: install the rcautofs(8) man page as a symbolic link
  to autofs(8)
- rpm spec: restart the automount daemon after updates
- init script: update Free Software Foundation address
* Tue Jun 14 2011 lchiquitto@novell.com
- fix null cache deadlock (bnc#696596)
* Tue Jun 14 2011 lchiquitto@novell.com
- update 5.0.5 upstream patches to 20110613 (bnc#699767):
  * remove master_mutex_unlock() leftover
  * fix sanity checks for brackets in server name
  * fix lsb service name in init script
  * fix map source check in file lookup
  * fix simple bind without SASL support
  * fix sasl bind host name selection
* Mon May  9 2011 lchiquitto@novell.com
- update 5.0.5 upstream patches to 20110427 (bnc#692104):
  * fix paged ldap map read
  * fix next task list update
  * fix stale map read
  * fix null cache clean
  * automount(8) man page correction
  * fix out of order locking in readmap
  * include ip address in debug logging
  * mount using address for DNS round robin host names
  * reset negative status on cache prune
- remove patches that are now upstream:
  * autofs-5.0.5-fix-next-task-list-update.patch
  * autofs-5.0.5-fix-stale-map-read.patch
  * autofs-5.0.5-fix-out-of-order-locking-in-readmap.patch
* Mon Apr  4 2011 lchiquitto@novell.com
- init script: use misc device (/dev/autofs) by default, unless it
  is explicitly disabled in sysconfig (bnc#684997)
* Mon Apr  4 2011 lchiquitto@novell.com
- fix out of order locking in readmap (bnc#667967)
* Mon Apr  4 2011 lchiquitto@novell.com
- add upstream fixes for the "non-expiring mounts" problem
  (bnc#677143, bnc#698589)
* Tue Mar 29 2011 lchiquitto@novell.com
- update 5.0.5 upstream patches to 20110318, fixing one bug:
  * replace GPLv3 code (bnc#682268)
* Thu Mar  3 2011 lchiquitto@novell.com
- update 5.0.5 upstream patches to 20110302 (bnc#676690):
  * use weight only for server selection
  * fix isspace() wild card substitution
  * auto adjust ldap page size
  * fix prune cache valid check
  * fix mountd vers retry
  * fix expire race
* Mon Feb 21 2011 lchiquitto@novell.com
- when ghosting is enabled, don't create mount points for cached
  entries that don't have a valid mapent (bnc#658734)
* Fri Oct 29 2010 lchiquitto@novell.com
- update 5.0.5 upstream patches to 20101021 (bnc#650177):
  * remove ERR_remove_state() openssl call
  * always read file maps mount lookup map read fix
  * fix direct map not updating on reread
  * fix add simple bind auth
  * fix submount shutdown wait
  * add external bind method
  * add dump maps option
* Thu Aug 19 2010 lchiquitto@novell.com
- add MAP_HASH_TABLE_SIZE option to sysconfig
* Thu Aug 12 2010 lchiquitto@novell.com
- update 5.0.5 upstream patches to 20100810 (bnc#630736):
  * remove extra read master map call
  * fix "fix cache_init() on source re-read"
  * fix error handing in do_mount_indirect()
  * expire thread use pending mutex
  * link against krb5 library by default
  * make "verbose" mode a little less verbose (bnc#630719)
- merge patches autofs-5.0.2-use_local_cflags.patch and
  autofs-5.0.5-as_needed.patch into autofs-suse-build.patch
- remove autofs-5.0.4-link_kerberos.patch (now upstream)
* Mon May 24 2010 lchiquitto@novell.com
- update 5.0.5 upstream patches to 20100524 (bnc#608284):
  * add support to LDAP simple bind authentication
  * fix master map source server unavailable handling
  * add autofs_ldap_auth.conf man page
  * fix random selection for host on different network
  * don't hold lock for simple mounts
  * fix remount locking
  * fix wildcard map entry match (bnc#585201)
  * fix parse_sun() module init
  * don't check null cache on expire
  * fix null cache race
  * fix cache_init() on source re-read
  * mapent becomes negative during lookup
  * check each dc server
  * fix negative cache included map lookup
  * remove state machine timed wait
* Mon May 10 2010 lchiquitto@novell.com
- init script: improve stop routine to avoid problems on restart
  (bnc#604497)
* Wed Mar 31 2010 lchiquitto@novell.com
- update 5.0.5 upstream patches to 20100326:
  * fix reconnect get base dn
  * add missing sasl mutex callbacks
  * fix get query dn failure
  * fix ampersand escape in auto.smb
  * add locality as valid ldap master map attribute
  * add locality as valid ldap master map attribute fix
* Wed Feb 24 2010 mszeredi@suse.cz
- add "network-remotefs" to  Should-Start: and  Should-Stop: in the
  init script (bnc#522224)
* Wed Feb 10 2010 lchiquitto@novell.com
- remove configure to make sure it will be recreated by autoconf.
  fixes a build problem that sometimes prevented lookup_ldap.so to
  be linked against krb5 (bnc#572934, bnc#578655)
* Thu Feb  4 2010 lchiquitto@novell.com
- update 5.0.5 upstream patches to 20100201:
  * check for path mount location in generic module
  * don't fail mount on access fail
  * fix rpc fail on large export list
  * fix memory leak on reload
  * don't connect at ldap lookup module init
  * fix random selection option
  * fix disable timeout
  * fix strdup() return value check
- include README file about active restart feature (bnc#565151)
* Wed Dec 23 2009 lchiquitto@novell.com
- fix build on releases that do not support ext4
* Wed Dec 16 2009 lchiquitto@novell.com
- add new sysconfig parameter USE_MISC_DEVICE and enable it by
  default (bnc#565151)
- update initscript bringing it closer to what we have upstream:
  * remove the deprecated force-stop logic and handle it like a
    regular stop
  * remove force-reload from usage and handle it like a regular
    reload
* Fri Nov 27 2009 lchiquitto@novell.com
- update to version 5.0.5. lots of bug fixes including:
  * fix nested submount expire deadlock
  * fix negative caching for non-existent map keys
  * make hash table scale to thousands of entries
  * fix uri list locking (again)
  * add nfs mount protocol default configuration option
  * fix bad token declaration in master map parser
  * fix double free in expire_proc()
  * fix file map lookup when reading included or nsswitch sources
  * fix memory leak reading master map
  * fix st_remove_tasks() locking
  * dont umount existing direct mount on master re-read
  * fix incorrect shutdown introduced by library relaod fixes
  * fix not releasing resources when using submounts
  * fix double free in sasl_bind()
  * fix map type info parse error
  * fix an RPC fd leak
  * fix pthread push order in expire_proc_direct()
  * fix libxml2 non-thread-safe calls
  * fix direct map cache locking
  * fix dont umount existing direct mount on reread.
- update 5.0.5 upstream patches to 20091124:
  * add mount wait parameter
  * don't use master_lex_destroy() to clear parse buffer
  * fix backwards #ifndef INET6
  * fix ext4 fsck at mount
  * fix included map read fail handling
  * fix libxml2 workaround configure
  * fix pidof init script usage
  * fix stale initialization for file map instance
  * fix timeout in connect_nb()
  * make documentation for set-log-priority clearer
  * refactor ldap sasl bind
  * special case cifs escapes.
* Fri Jun 19 2009 cmorve69@yahoo.es
- fixed build with --as-needed
* Thu May 14 2009 werner@suse.de
- Add nfsserver to should start/stop in rc script (bnc#467906)
* Thu Apr  9 2009 werner@suse.de
- make sure that submounts are not busy anymore (bnc#467906)
* Thu Feb 12 2009 mkoenig@suse.de
- add script to fetch upstream patches
* Wed Feb  4 2009 mkoenig@suse.de
- update to version 5.0.4 (just version bump, since all 5.0.3
  upstream patches had been already applied)
- update 5.0.4 upstream patches to 20090122:
  * fix dumb libxml2 check
  * fix nested submount expire deadlock.
  * fix negative caching for non-existent map keys.
  * use CLOEXEC flag.
  * fix select(2) fd limit.
  * make hash table scale to thousands of entries (Paul Wankadia,
    Valerie Aurora Henson).
  * clear the quoted flag after each character from program map input.
- remove patch
  autofs-5.0.1-mount_xdr_no_strict_aliasing.patch
* Tue Jan 27 2009 kukuk@suse.de
- Add aaa_base to PreReq.
* Fri Jan 23 2009 coolo@suse.de
- don't rely on huge perl script to check if autofs is active
* Thu Jan 22 2009 mkoenig@suse.de
- apply all 5.0.3 upstream patches which include a couple
  critical bugfixes:
- fix segfault due to empty hostlist [bnc#466167]
- fixes for submount shutdown
- use /dev/urandom
- fix problems if /etc/mtab points to /proc/mounts
- dynamically allocate interface config buffer
- fix percent hack
- handle zero length nis key update
- fix file handle being left open following a multi-mount non-fatal
  mount fail
- fix case where an incorrect mount point path was being used when
  mounting a multi-mount component
- Fix incorrect match of map type as a host name
- fix map out of order map re-read on hup signal.
- fix nisplus error return check and use after free error.
- fix rootless direct multi-mount expire.
- wait submount expire thread completion
- add missing uris list locking
- fix master map lexer eval order
- fix bad alloca usage
* Thu Jan  8 2009 mkoenig@suse.de
- fix segfault on HUP [bnc#458336]
* Fri Oct 24 2008 mkoenig@suse.de
- fix syntax error in init script [bnc#435505]
* Fri Aug 15 2008 mkoenig@suse.de
- build with --enable-ignore-busy
- add init script action force-expire to force the expire
  of mounted filesystems
- add init script action force-stop for forced shutdown with
  lazy umount of busy filesystems
- use force-stop on shutdown
- Don't kill all processes on busy filesystems anymore,
  as we do a lazy umount, this might not be needed and
  reduces shutdown overhead
* Mon Aug 11 2008 mkoenig@suse.de
- update upstream patches 20080806
- remove patch
  autofs-5.0.3-allow_rootfs_nonlocal.patch
* Thu Jun 26 2008 mkoenig@suse.de
- update upstream patches 20080528
- allow rootfs to be non-local [bnc#399944]
- remove patch
  autofs-5.0.3-aclocal_pthread.patch
* Fri May 16 2008 mkoenig@suse.de
- more shutdown improvements to minimize the risk of mounted
  leftovers in the shutdown process
  differentiate between direct/indirect mounts
  enforce lazy umount since USR2 seems not to work currently
* Mon Apr 21 2008 mkoenig@suse.de
- improve shutdown in init script
* Wed Jan 30 2008 mkoenig@suse.de
- link LDAP lookup module with krb5 if build with SASL [bnc#356599]
* Thu Jan 17 2008 mkoenig@suse.de
- update to version 5.0.3
  * quell annoying "cannot open mount module" message.
  * fix for improve handling of server not available.
  * use mount option "nodev" for "-hosts" map unless "dev" is
    explicily specified.
  * add LDAP paged query handling to deal with query size restrictions
  * add additional case for "mark map instances stale so they aren't
    "cleaned" during updates".
  * fix race during sub-mount shutdown.
  * fix add SEARCH_BASE configuration option.
  * update kernel patches.
- update upstream patches (20080117)
  * correct configure test for ldapr page control functions.
  * catch "-xfn" map type and issue "no supported" message.
- fix configure check
- add krb5-devel and libxml2-devel to BuildRequires
* Mon Dec 17 2007 mkoenig@suse.de
- update upstream patches
  * fix off-by-one error for lookup of map keys exactly
    255 characters long
  * improve handling of server not available
  * fix LDAP_URI server selection
  * add authentication option for using an external credential cache
  * expand support for the "%%" hack
  * fix to quoting for exports gathered by hosts map
  * use mount option "nosuid" for "-hosts" map unless "suid" is
    explicily specified
  * second attempt fixing quoting for exports gathered by hosts map
- merged autofs-5.0.2-size_fix.patch
* Tue Nov 20 2007 mkoenig@suse.de
- fix buffer overflow [#341626]
* Thu Nov 15 2007 dmueller@suse.de
- add recommends on nfs-client
* Wed Nov 14 2007 mkoenig@suse.de
- fix version
* Fri Nov  9 2007 mkoenig@suse.de
- update upstream patches which include several bugfixes.
- fix build of debuginfo package, in which the info for the
  daemon has been missing
* Thu Oct 18 2007 mkoenig@suse.de
- add $portmap to ShouldStart [#331615]
- fix problem with nested mounts [#128083]
* Wed Sep 19 2007 mkoenig@suse.de
- fix last change [#309123]
* Mon Sep 17 2007 mkoenig@suse.de
- kill processes which keep filesystem busy on shutdown [#309123]
* Wed Jul 25 2007 mkoenig@suse.de
- add BuildRequires e2fsprogs
  and mention modules to be build explicitly in %%files
* Thu Jul 19 2007 mkoenig@suse.de
- new sysconfig parameters LOCAL_OPTIONS and APPEND_OPTIONS
  support for default mount options to optionally are appended
  to master map options or replace them.
- enable LFS support to avoid problems with mount expires
* Thu Jul  5 2007 mkoenig@suse.de
- update to version 5.0.2:
  * bugfix release
- new upstream patches
  autofs-5.0.2-add-krb5-include.patch
  autofs-5.0.2-bad-proto-init.patch
  autofs-5.0.2-add-missing-multi-support.patch
  autofs-5.0.2-add-multi-nsswitch-lookup.patch
- removed patch (merged upstream)
  autofs-5.0.1-fix_contained_check.patch
* Thu Apr 26 2007 mkoenig@suse.de
- update to version 5.0.1:
  * autofs5 is a major rewrite
  * many new features to be more compliant with industry standard:
    + improved direct mount map support
    + '+' map inclusion
    + added nsswitch map source support
    + rewrote multi-mount map code
    + added LDAP encryption and authentication support
    + improved shutdown and restart
    + a "hosts" map module has been added
- add gssd dependencies in init script [#249779]
* Tue Mar  6 2007 mkoenig@suse.de
- Fix last upstream patch which introduced a problem for
  filesystems defined in fstab by LABEL or UUID [#244945]
- Fix killing of processes on stop [#249770]
* Wed Jan 31 2007 mkoenig@suse.de
- add upstream patch autofs-4.1.4-dont_create_remote_dirs.patch
  Checks first for the directory to create in order to avoid
  problems with different mkdir behaviour, resolves [#229607]
* Mon Jan 29 2007 mkoenig@suse.de
- remove the introduced -multi option, because this issue has
  been fixed upstream in a different way.
  add autofs-4.1.4-multi_parse_fix.patch, resolves [#232855]
* Thu Nov 30 2006 mkoenig@suse.de
- add NetworkManager dispatcher script [#173990]
- fix possible buffer overflow
* Wed Oct  4 2006 jeffm@suse.com
- Fixed nfs mount connect retry fallback (195924)
- Fixed e2fsck error handling (196057)
* Tue Sep 12 2006 schwab@suse.de
- Clean up init script.
* Tue Sep 12 2006 ro@suse.de
- fix typo in comment for previous change
* Tue Sep 12 2006 ro@suse.de
- add previous defaults to newly added variable names in rcscript
* Thu Sep  7 2006 jeffm@suse.com
- Added -multi option to enable consistent mount
  behavior when using auto.net (118902)
* Tue Aug 29 2006 jeffm@suse.com
- Fixed --timeout=<num> handling (117672)
- Fixed forced expiry handling (SIGHUP vs SIGUSR1) (177068)
* Wed Aug 23 2006 jeffm@suse.com
- Added configurable locking patch (178308)
* Fri May 26 2006 schwab@suse.de
- Fix broken makefile.
* Sat May 20 2006 schwab@suse.de
- Don't strip binaries.
* Wed May 17 2006 seife@suse.de
- Add README.NetworkManager [#175935]
* Tue Feb 28 2006 cthiel@suse.de
- fix post script
* Wed Feb  1 2006 rhafer@suse.de
- Support for ':' in ldap mapentries [#117297]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov 23 2005 varkoly@suse.de
- Add -fno-strict-aliasing to the CFLAGS
* Mon Nov 14 2005 varkoly@suse.de
- Bugfix: bad example ldif.
* Sun Sep 25 2005 ro@suse.de
- added LDAP_DEPRECATED to compile flags
* Thu Sep  1 2005 choeger@suse.de
- Bugfix ID#112779 - autofs uses /etc/openldap/ldap.conf instead of
  /etc/ldap.conf
* Thu Aug 25 2005 kukuk@suse.de
- Add ldap to Should-Start [#112984]
* Thu Aug 11 2005 mmj@suse.de
- make sure autofs is enabled after an update [#102944]
- don't support upgrading from <= SuSE Linux 7.3 anymore
* Sat Jul 23 2005 trenn@suse.de
- move /usr/lib64/autofs/autofs-ldap-auto-master to /usr/lib/autofs
  on x86_64 systems
* Fri Jun 17 2005 kukuk@suse.de
- Rename from autofs4 to autofs
* Tue Jun 14 2005 kukuk@suse.de
- Remove broken "singnal-race" patch [#90521]
* Sun May 22 2005 ro@suse.de
- update to 4.1.4, remove upstream patches
* Sun May 15 2005 aj@suse.de
- Initialize variables.
* Wed Apr 27 2005 meissner@suse.de
- use RPM_OPT_FLAGS
* Thu Apr  7 2005 kukuk@suse.de
- Remove autofs-4.1.0-loop.patch, it is wrong.
* Fri Mar  4 2005 arvin@suse.de
- use our good old init script (bug #67311)
* Fri Mar  4 2005 arvin@suse.de
- fixed syntax of sysconfig.autofs (bug #70883)
* Fri Feb 25 2005 mmj@suse.de
- LSB says return value for not running service is 7 [#65817]
* Thu Dec  9 2004 ihno@suse.de
- Update to version 4.1.3 plus patches
* Tue Jun 22 2004 ro@suse.de
- remove nfslock dependency from startscript
* Mon Apr 19 2004 arvin@suse.de
- make AutoBuild happy
* Fri Oct 31 2003 arvin@suse.de
- build rpm as non-root user
* Fri Oct 24 2003 arvin@suse.de
- updated to version 4.0.0
* Wed Oct 22 2003 arvin@suse.de
- fixed truncation of LDAP search DN after whitespace (bug #31847)
* Mon Aug 18 2003 arvin@suse.de
- added activation metadata (bug #28838)
* Mon Jul 28 2003 arvin@suse.de
- added documentation about syntax of auto.master file
* Wed Apr 23 2003 arvin@suse.de
- adapted option for sort in auto.net to new coreutils
* Mon Apr 14 2003 arvin@suse.de
- faster shutdown of service autofs (bug #25790)
* Fri Apr 11 2003 arvin@suse.de
- fixed handling of certain yp maps (bug #26274)
* Wed Feb  5 2003 arvin@suse.de
- set syslogmask back to not include debug messages
* Tue Jan 21 2003 mc@suse.de
- add a patch to support ldap v3
* Mon Jan 20 2003 arvin@suse.de
- strip autofs-ldap-auto-master tool
* Mon Jan 20 2003 mc@suse.de
- add better ldap support
- add ldap schema patch to support the nis schema with ldap
- add the Linux autofs.schema
- add a README about autofs and ldap
* Thu Dec 19 2002 arvin@suse.de
- added sysconfig metadata (bug #22615)
- better description in start script for runlevel editor
  (bug #21894)
- nicer output of init script
- start: check if daemon runs and export skipped if not configured
* Mon Sep  2 2002 arvin@suse.de
- remove lock file during stop even if no daemon is running
  (bug #18699)
* Tue Aug 27 2002 arvin@suse.de
- commented auto.misc entry in auto.master (bug #18434)
* Mon Aug 26 2002 arvin@suse.de
- include special dirs in package
* Fri Aug 23 2002 arvin@suse.de
- honor RPM_OPT_FLAGS
- moved plugins to %%{_libdir}/autofs
* Wed Aug  7 2002 ro@suse.de
- added Should-Start nfslock in rcscript (#17425)
* Thu Aug  1 2002 arvin@suse.de
- added requires and prerequires
* Mon Jul 22 2002 sf@suse.de
- updated auto_fs.h to actual version of kernel
* Thu Jul 18 2002 arvin@suse.de
- moved ypbind and keyserv to Should-Start in init script
  (bug #17064)
* Mon Feb 25 2002 arvin@suse.de
- added option expire to init script (unmount all currently
  not used mounts)
* Sat Feb 16 2002 arvin@suse.de
- fixed start/stop message
* Fri Feb 15 2002 arvin@suse.de
- simplify remove_and_set call
* Fri Feb 15 2002 arvin@suse.de
- better examples in /etc/auto.misc
* Fri Feb  1 2002 arvin@suse.de
- fixed restart and force-reload to stop and start the service
  (bug #13019)
* Wed Jan 23 2002 arvin@suse.de
- don't use default value of yes for removal of USE_NIS_FOR_AUTOFS
* Sat Jan 19 2002 arvin@suse.de
- read mount types to query from /etc/nsswitch.conf
* Wed Jan 16 2002 arvin@suse.de
- compile ldap lookup
* Wed Dec 12 2001 ro@suse.de
- moved rc.config.d -> sysconfig
* Mon Dec  3 2001 arvin@suse.de
- source /etc/rc.status in init script
* Fri Nov 23 2001 ro@suse.de
- correct (and simplify) insserv macro call
* Wed Nov 21 2001 arvin@suse.de
- removed rc-variable START_AUTOFS
* Sat Nov 17 2001 arvin@suse.de
- Added keyserv to Required-Start (bug #12233)
* Thu Sep  6 2001 kukuk@suse.de
- Use $network, $syslog and add $remote_fs [Bug #9908]
* Wed Sep  5 2001 bjacke@suse.de
- correct name of autosf.rc.config
* Fri Aug 31 2001 arvin@suse.de
- ignore direct maps (bug #9978)
* Mon Jul 30 2001 arvin@suse.de
- read /etc/rc.config.d/autofs.rc.config in init script
* Mon Jul 30 2001 arvin@suse.de
- create /etc/rc.config.d/autofs.rc.config (bug #9471)
* Mon Jul 23 2001 arvin@suse.de
- LSB compliant init script (bug #8973)
- files and executable maps for nis and nisplus (bug #8984)
* Wed May 16 2001 arvin@suse.de
- fixed compile warnings on ia64
* Mon Apr 30 2001 arvin@suse.de
- unset PS_PERSONALITY and CMD_ENV in init script (fix for
  bug #7436)
* Sun Apr 22 2001 arvin@suse.de
- update to autofs 4.0.0pre10
* Wed Apr 18 2001 arvin@suse.de
- increased blocksize to 8k in auto.net
* Tue Apr 17 2001 arvin@suse.de
- remove old provides
* Tue Apr 17 2001 arvin@suse.de
- renamed package to autofs4 (no provides or obsoletes, since
  autofs version 3 will be used by default)
* Mon Apr  9 2001 arvin@suse.de
- fixed restart function in init script
* Fri Mar  9 2001 arvin@suse.de
- added note in /etc/auto.master (bug #6660)
- use test -x instead of test -e in init script
* Thu Mar  1 2001 ro@suse.de
- fixed neededforbuild
* Tue Feb 13 2001 arvin@suse.de
- fixed killing of processes using autofs during shutdown
* Fri Jan 12 2001 arvin@suse.de
- changed start point in init script (fix for bug #5622)
* Tue Jan  2 2001 arvin@suse.de
- clear mountoptions in loop for reading auto.master in init script
* Tue Nov 28 2000 arvin@suse.de
- kill processes using automounted filesystems when going
  into runlevel 0 or 6
* Mon Nov 27 2000 arvin@suse.de
- moved init script from /sbin/init.d to /etc/init.d
* Wed Nov 22 2000 arvin@suse.de
- use insserv in post-install for creating init.d scripts
- fixed parsing of "--timeout" option in /etc/auto.master,
  partly fix for bug #4356
* Wed Nov  8 2000 arvin@suse.de
- turned off debug messages to syslogd
* Thu Nov  2 2000 arvin@suse.de
- added option nonstrict in auto.net
* Thu Nov  2 2000 arvin@suse.de
- new version 4.0.0pre9
* Tue Oct 24 2000 arvin@suse.de
- new version 4.0.0pre8
* Mon Oct 23 2000 bk@suse.de
- remove the annoying dequote debug message(filled the logs without errors)
* Sun Oct 15 2000 ro@suse.de
- showmount does no longer have the k-prefix
* Fri Oct  6 2000 schwab@suse.de
- Avoid OPEN_MAX.
* Wed Sep 27 2000 arvin@suse.de
- even more improved auto.net
* Tue Sep 26 2000 arvin@suse.de
- improved auto.net
- changed to bz2 source archive
* Thu Sep 21 2000 arvin@suse.de
- fixed rcautofs (some lines in status were truncated)
* Tue Sep 19 2000 arvin@suse.de
- fixed bug #3842 (wrong option to mount; was actually random data)
* Tue Aug 22 2000 ro@suse.de
- changed neededforbuild: knfsd -> nfsutils
* Thu Jul  6 2000 kukuk@suse.de
- Fix path to showmount in /etc/auto.net
* Mon May  8 2000 rolf@suse.de
- new version 4.0.0pre7
- fix bug in rcautofs [BUG#2737]
* Sat Feb 26 2000 kukuk@suse.de
- Add patch from beta list for multiple entries
* Tue Feb 15 2000 kukuk@suse.de
- Include own showmount
- Update to autofs 4.0.0pre6
* Sun Jan 30 2000 kukuk@suse.de
- Update to autofs 4.0.0pre2
- Add rc.config variable for autofs options (like --timeout)
- Add NIS+ support to /sbin/init.d/autofs
- Mark /etc/auto.* files as %%config(noreplace)
- Add /etc/auto.net (needs new autofs kernel module)
* Fri Nov  5 1999 rolf@suse.de
- added flag to switch NIS usage for maps [BUG#1074]
* Mon Oct 25 1999 ro@suse.de
- specfile-fix: no need for %%dir /usr/lib/autofs, if that whole tree
  is packed
* Mon Oct 25 1999 rolf@suse.de
- status now tells whether process is running [BUG#732]
* Sat Oct 23 1999 kukuk@suse.de
- Fix problems with new samba 2.0.x versions [BUG#361]
- Fix typos and loop problem
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Jun 22 1999 kukuk@suse.de
- added lookup_nisplus.so, mount_autofs.so, mount_ext2.so
* Wed Dec  9 1998 rolf@suse.de
- added /usr/sbin/rcautofs
* Fri Nov 27 1998 rolf@suse.de
- mount timeout added in init script
* Tue Nov 24 1998 rolf@suse.de
- new version 3.1.3
- modified init script
- unset localoptions
* Sat Sep 19 1998 ro@suse.de
- define _GNU_SOURCE where getopt_long is used
* Fri Apr 17 1998 rolf@suse.de
- set localoptions to rsize=8192,wsize=8192
  cleaned up /etc/auto.misc
* Mon Apr  6 1998 ro@suse.de
- update to 3.1.0
* Mon Mar  2 1998 ro@suse.de
- marked startscript and files in etc as config
* Mon Feb  9 1998 rolf@suse.de
- fixed startup script in /sbin/init.d/ for restart
* Wed Nov 12 1997 rolf@suse.de
- minor big fix
* Thu Oct 16 1997 rolf@suse.de
- new version autofs-0.3.14
* Thu Sep 11 1997 rolf@suse.de
- made package from autofs-0.3.9
